@@ -13,12 +13,12 @@
 # limitations under the License.
 
 import logging
-import mock
 import os
 import socket
 
 from keystoneauth1 import adapter
-from mox3 import mox
+import mock
+import mox
 from oslo_serialization import jsonutils
 import requests
 import six
